==> pyFAI-0.12.0-cp35-cp35m-win_amd64.whl: pyFAI-0.12.0.data/scripts/diff_map.py <==
#!C:\Program Files\Python 3.5\python.exe
# -*- coding: utf-8 -*-
#
#    Project: Azimuthal integration
#             https://github.com/kif/pyFAI
#
#    Copyright (C) European Synchrotron Radiation Facility, Grenoble, France
#
#    Authors: Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
#             Picca Frédéric-Emmanuel <picca@synchrotron-soleil.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
diff_tomo

A tool for fast processing of diffraction tomography
"""

__author__ = "Jerome Kieffer"
__contact__ = "Jerome.Kieffer@ESRF.eu"
__license__ = "GPLv3+"
__copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
__date__ = "25/11/2015"
__satus__ = "Production"

import logging
import sys
logging.basicConfig(level=logging.INFO)
logger = logging.getLogger("diff_tomo")
from pyFAI.diffmap import DiffMap


if __name__ == "__main__":
    dt = DiffMap()
    options, config = dt.parse(with_config=True)

    if not options.gui:
        dt.setup_ai()
        dt.makeHDF5()
        dt.process()
        dt.show_stats()
    else:
        from pyFAI.gui_utils import QtGui
        from pyFAI.diffmap_widget import DiffMapWidget
        app = QtGui.QApplication([])
        window = DiffMapWidget()
        window.set_config(config)
#         window.restore()
        window.show()
        sys.exit(app.exec_())

==> pyFAI-0.13.0-cp35-cp35m-win_amd64.whl: pyFAI-0.13.0.data/scripts/diff_map.py <==
#!C:\Python35-amd64\python.exe
# -*- coding: utf-8 -*-
#
#    Project: Azimuthal integration
#             https://github.com/kif/pyFAI
#
#    Copyright (C) European Synchrotron Radiation Facility, Grenoble, France
#
#    Authors: Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
#             Picca Frédéric-Emmanuel <picca@synchrotron-soleil.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
diff_tomo

A tool for fast processing of diffraction tomography
"""

__author__ = "Jerome Kieffer"
__contact__ = "Jerome.Kieffer@ESRF.eu"
__license__ = "GPLv3+"
__copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
__date__ = "26/10/2016"
__satus__ = "Production"

import logging
import sys
logging.basicConfig(level=logging.INFO)
logger = logging.getLogger("diff_tomo")
from pyFAI.diffmap import DiffMap


if __name__ == "__main__":
    dt = DiffMap()
    options, config = dt.parse(with_config=True)

    if not options.gui:
        dt.setup_ai()
        dt.makeHDF5()
        dt.process()
        dt.show_stats()
    else:
        from pyFAI.gui import qt
        from pyFAI.diffmap_widget import DiffMapWidget
        app = qt.QApplication([])
        window = DiffMapWidget()
        window.set_config(config)
#         window.restore()
        window.show()
        sys.exit(app.exec_())
